@@ -777,7 +777,7 @@ void Task::parseLegacy(const std::string& line) {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Task::composeJSON(bool decorate /*= false*/) const {
+std::string Task::composeJSON(bool decorate /*= false*/) {
   std::stringstream out;
   out << '{';
 
@@ -894,7 +894,7 @@ std::string Task::composeJSON(bool decorate /*= false*/) const {
 
 #ifdef PRODUCT_TASKWARRIOR
   // Include urgency.
-  if (decorate) out << ',' << "\"urgency\":" << urgency_c();
+  if (decorate) out << ',' << "\"urgency\":" << urgency();
 #endif
 
   out << '}';
@@ -928,7 +928,7 @@ void Task::addAnnotation(const std::string& description) {
     ++now;
   } while (has(key));
 
-  data[key] = json::decode(description);
+  data[key] = description;
   ++annotation_count;
   recalc_urgency = true;
 }
@@ -1999,7 +1999,7 @@ void Task::modify(modType type, bool text_required /* = false */) {
           // Delegate modification to the column object or their base classes.
           if (name == "depends" || name == "tags" || name == "recur" || column->type() == "date" ||
               column->type() == "duration" || column->type() == "numeric" ||
-              column->type() == "string") {
+              column->type() == "string" || column->type() == "uuid") {
             column->modify(*this, value);
             mods = true;
           }
