@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -21,29 +20,27 @@
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// http://www.opensource.org/licenses/mit-license.php
+// https://www.opensource.org/licenses/mit-license.php
 //
 ////////////////////////////////////////////////////////////////////////////////
 
 #ifndef INCLUDED_CMDUDAS
 #define INCLUDED_CMDUDAS
-#define L10N                                           // Localization complete.
 
-#include <string>
 #include <Command.h>
 
-class CmdUDAs : public Command
-{
-public:
-  CmdUDAs ();
-  int execute (std::string&);
+#include <string>
+
+class CmdUDAs : public Command {
+ public:
+  CmdUDAs();
+  int execute(std::string&);
 };
 
-class CmdCompletionUDAs : public Command
-{
-public:
-  CmdCompletionUDAs ();
-  int execute (std::string&);
+class CmdCompletionUDAs : public Command {
+ public:
+  CmdCompletionUDAs();
+  int execute(std::string&);
 };
 
 #endif
