@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2020, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,14 +27,14 @@
 #ifndef INCLUDED_CMDURGENCY
 #define INCLUDED_CMDURGENCY
 
-#include <string>
 #include <Command.h>
 
-class CmdUrgency : public Command
-{
-public:
-  CmdUrgency ();
-  int execute (std::string&);
+#include <string>
+
+class CmdUrgency : public Command {
+ public:
+  CmdUrgency();
+  int execute(std::string&);
 };
 
 #endif
